/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { FieldKey } from "../schema-stored/index.js";
import { RevisionTagCodec } from "../rebase/index.js";
import { ICodecOptions } from "../../codec/index.js";
import { PlaceIndex, Range } from "./pathTree.js";
import { DetachedFieldIndex } from "./detachedFieldIndex.js";
import { DeltaVisitor } from "./visitDelta.js";
import { ProtoNodes, Root } from "./delta.js";
export declare function makeDetachedFieldIndex(prefix: string | undefined, revisionTagCodec: RevisionTagCodec, options?: ICodecOptions): DetachedFieldIndex;
export declare function applyDelta(delta: Root, deltaProcessor: {
    acquireVisitor: () => DeltaVisitor;
}, detachedFieldIndex: DetachedFieldIndex): void;
export declare function announceDelta(delta: Root, deltaProcessor: {
    acquireVisitor: () => DeltaVisitor & AnnouncedVisitor;
}, detachedFieldIndex: DetachedFieldIndex): void;
export declare function combineVisitors(visitors: readonly DeltaVisitor[], announceVisitors?: readonly AnnouncedVisitor[]): DeltaVisitor;
/**
 * Visitor that is notified of changes before, after, and when changes are made.
 * Must be freed after use.
 * @internal
 */
export interface AnnouncedVisitor {
    /**
     * A hook that is called after all nodes have been created.
     */
    afterCreate(content: ProtoNodes, destination: FieldKey): void;
    beforeDestroy(field: FieldKey, count: number): void;
    beforeAttach(source: FieldKey, count: number, destination: PlaceIndex): void;
    afterAttach(source: FieldKey, destination: Range): void;
    beforeDetach(source: Range, destination: FieldKey): void;
    afterDetach(source: PlaceIndex, count: number, destination: FieldKey): void;
    beforeReplace(newContent: FieldKey, oldContent: Range, oldContentDestination: FieldKey): void;
    afterReplace(newContentSource: FieldKey, newContent: Range, oldContent: FieldKey): void;
}
//# sourceMappingURL=visitorUtils.d.ts.map