"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeOptionalFieldCodecFamily = exports.noChangeCodecFamily = void 0;
const typebox_1 = require("@sinclair/typebox");
const index_js_1 = require("../../codec/index.js");
const changeAtomIdCodec_js_1 = require("../changeAtomIdCodec.js");
const optionalFieldChangeFormat_js_1 = require("./optionalFieldChangeFormat.js");
exports.noChangeCodecFamily = (0, index_js_1.makeCodecFamily)([[0, index_js_1.unitCodec]]);
const makeOptionalFieldCodecFamily = (childCodec, revisionTagCodec) => (0, index_js_1.makeCodecFamily)([[0, makeOptionalFieldCodec(childCodec, revisionTagCodec)]]);
exports.makeOptionalFieldCodecFamily = makeOptionalFieldCodecFamily;
function makeRegisterIdCodec(revisionTagCodec) {
    const changeAtomIdCodec = (0, changeAtomIdCodec_js_1.makeChangeAtomIdCodec)(revisionTagCodec);
    return {
        encode: (registerId, context) => {
            if (registerId === "self") {
                return null;
            }
            return changeAtomIdCodec.encode(registerId, context);
        },
        decode: (registerId, context) => {
            if (registerId === null) {
                return "self";
            }
            return changeAtomIdCodec.decode(registerId, context);
        },
        encodedSchema: optionalFieldChangeFormat_js_1.EncodedRegisterId,
    };
}
function makeOptionalFieldCodec(childCodec, revisionTagCodec) {
    const registerIdCodec = makeRegisterIdCodec(revisionTagCodec);
    return {
        encode: (change, context) => {
            const encoded = {};
            if (change.moves.length > 0) {
                encoded.m = [];
                for (const [src, dst, type] of change.moves) {
                    encoded.m.push([
                        registerIdCodec.encode(src, context),
                        registerIdCodec.encode(dst, context),
                        type === "nodeTargeting",
                    ]);
                }
            }
            if (change.childChanges.length > 0) {
                encoded.c = [];
                for (const [id, childChange] of change.childChanges) {
                    encoded.c.push([
                        registerIdCodec.encode(id, context),
                        childCodec.encode(childChange, context),
                    ]);
                }
            }
            if (change.reservedDetachId !== undefined) {
                encoded.d = registerIdCodec.encode(change.reservedDetachId, context);
            }
            return encoded;
        },
        decode: (encoded, context) => {
            const moves = encoded.m?.map(([src, dst, type]) => [
                registerIdCodec.decode(src, context),
                registerIdCodec.decode(dst, context),
                type ? "nodeTargeting" : "cellTargeting",
            ]) ?? [];
            const decoded = {
                moves,
                childChanges: encoded.c?.map(([id, encodedChange]) => [
                    registerIdCodec.decode(id, context),
                    childCodec.decode(encodedChange, context),
                ]) ?? [],
            };
            if (encoded.d !== undefined) {
                decoded.reservedDetachId = registerIdCodec.decode(encoded.d, context);
            }
            return decoded;
        },
        encodedSchema: (0, optionalFieldChangeFormat_js_1.EncodedOptionalChangeset)(childCodec.encodedSchema ?? typebox_1.Type.Any()),
    };
}
//# sourceMappingURL=optionalFieldCodecs.js.map