"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckoutFlexTreeView = void 0;
const index_js_1 = require("../feature-libraries/index.js");
const index_js_2 = require("../util/index.js");
/**
 * Implementation of FlexTreeView wrapping a ITreeCheckout.
 */
class CheckoutFlexTreeView {
    constructor(checkout, schema, nodeKeyManager, nodeKeyFieldKey, onDispose) {
        this.checkout = checkout;
        this.schema = schema;
        this.nodeKeyManager = nodeKeyManager;
        this.nodeKeyFieldKey = nodeKeyFieldKey;
        this.onDispose = onDispose;
        this.context = (0, index_js_1.getTreeContext)(schema, this.checkout.forest, this.checkout.editor, nodeKeyManager, nodeKeyFieldKey);
        this.flexTree = this.context.root;
    }
    [index_js_2.disposeSymbol]() {
        this.context[index_js_2.disposeSymbol]();
        this.onDispose?.();
    }
    fork() {
        const branch = this.checkout.fork();
        return new CheckoutFlexTreeView(branch, this.schema, this.nodeKeyManager, this.nodeKeyFieldKey);
    }
}
exports.CheckoutFlexTreeView = CheckoutFlexTreeView;
//# sourceMappingURL=treeView.js.map